@@ -6,12 +6,16 @@
 #include <qstring.h>
 
 // libept now provides a header for forward declarations
-#include <ept/forward.h>
-#include <ept/configuration/apt.h>
+//#include <ept/forward.h>
+//#include <ept/configuration/apt.h>
 
 #include <string>
 #include <set>
 
+namespace ept {
+class Aggregator;
+}
+
 class QPushButton;
 class QStatusBar;
 class QWidget;
@@ -39,7 +43,7 @@ class IProvider
 {
 public:
 	// Shortcut to point to the ept aggregator type
-	typedef ept::configuration::apt::cache::Aggregator Aggregator;
+	typedef ept::Aggregator Aggregator;
 
 	/** @brief Returns the path were the icons are located. */
 	virtual QString iconDir() const = 0;
