@@ -16,7 +16,7 @@
 #include <qapplication.h>
 #include <QMessageBox>
 
-#include <ept/init.h>
+//#include <ept/init.h>
 #if 0
 #include <apt-front/cache/cache.h>
 #include <apt-front/cache/component/packagetags.h>
@@ -94,6 +94,7 @@ int main(int argc, char* argv[])
 	}
 	catch (aptFront::exception::Exception e)
 #endif
+/*
 	try {
 		ept::init();
 	} 
@@ -109,6 +110,7 @@ int main(int argc, char* argv[])
 			"OK"
 		);
 	}
+*/
 	PackageSearchImpl search(0, "MainWindow");
 	search.setCaption("Debian Package Search - Version " + NPackageSearch::VERSION);
 	search.show();
