@@ -35,11 +35,7 @@
 #include <QToolBar>
 #include <QWhatsThis>
 
-#if 0
-#include <apt-front/cache/cache.h>
-#endif
-#include <ept/configuration/apt.h>
-#include <ept/cache/apt/packages.h>
+#include "aggregator.h"
 #include <wibble/operators.h>
 
 
@@ -1076,8 +1072,8 @@ void PackageSearchImpl::setPackageActionsEnabled(bool enabled)
 // Include template instantiations as well
 // Need to undef emit because it's been defined by qt as something else
 #undef emit
-#include <ept/cache/apt/packages.tcc>
-#include <ept/cache/debtags/vocabulary.tcc>
+//#include <ept/cache/apt/packages.tcc>
+//#include <ept/cache/debtags/vocabulary.tcc>
 // Luckily, qt defines emit as an empty symbol, so it's easy to redefine it here
 #define emit
 
