@@ -16,8 +16,8 @@
 #include <tagcoll/Expression.h>
 #include <tagcoll/Filter.h>
 #include <tagcoll/Exception.h>
-#endif
 #include <ept/cache/debtags/tagmap.h>
+#endif
 
 
 #include <helpers.h>
@@ -40,7 +40,7 @@
 #include "choosentagsdisplay.h"
 
 
-typedef ept::configuration::apt::cache::Package Package;
+typedef std::string Package;
 
 
 namespace NPlugin
@@ -179,7 +179,7 @@ QString DebtagsPlugin::informationText(const string& package)
 {
 	{	// add the tags of the package to the description
 		Package packageEntity= NUtil::getPackageByName(package);
-		if (!packageEntity.valid())
+		if (packageEntity.empty())
 			throw NPlugin::PackageNotFoundException(package);
 		std::set<string> tagset = NUtil::tagsToStrings(_container.collection()->getTagsOfItem(packageEntity));
 		if (tagset.empty()) return _emptyString;
@@ -283,6 +283,6 @@ void DebtagsPlugin::setWidgetsEnabled(bool enabled)
 }	// namespace NPlugin
 
 #undef emit
-#include <ept/cache/apt/packages.tcc>
-#include <ept/cache/debtags/vocabulary.tcc>
-#include <ept/cache/tag.tcc>
+//#include <ept/cache/apt/packages.tcc>
+//#include <ept/cache/debtags/vocabulary.tcc>
+//#include <ept/cache/tag.tcc>
