@@ -6,12 +6,18 @@
 #include <qobject.h>
 #include <qstring.h>
 
-#include <ept/configuration/apt.h>
+#include <ept/debtags/tag.h>
 
 #include <baseplugincontainer.h>
 
 using namespace std;
 
+namespace ept {
+namespace debtags {
+class Debtags;
+}
+}
+
 namespace NApplication
 {
 	class RunCommand;
@@ -33,9 +39,9 @@ class RelatedPlugin;
   */
 class DebtagsPluginContainer : public QObject, public BasePluginContainer 
 {
-	typedef ept::configuration::apt::cache::Facet Facet;
-	typedef ept::configuration::apt::cache::TagMap TagMap;
-	typedef ept::configuration::apt::cache::Vocabulary Vocabulary;
+	typedef ept::debtags::Facet Facet;
+	typedef ept::debtags::Debtags Debtags;
+	typedef ept::debtags::Vocabulary Vocabulary;
 
 	Q_OBJECT
 	/** @brief This holds a list of the names of all the plugins offered by this 
@@ -113,7 +119,7 @@ public:
 	  *
 	  * Every item (package) appears only ones in the collection. 
 	  */
-	TagMap* collection() const;
+	Debtags* collection() const;
 protected:
 	/** @brief This sets the debtags operations to be enabled/ disabled 
 	  *
