@@ -9,7 +9,7 @@
 #include <qpushbutton.h>
 
 #include <tagcoll/utils/set.h>
-#include <ept/cache/debtags/tagmap.h>
+//#include <ept/cache/debtags/tagmap.h>
 
 // NUtil
 #include <helpers.h>
@@ -189,7 +189,7 @@ void RelatedPlugin::evaluateSearch()
 			std::set<Package> result = _container.collection()->getRelatedItems(tags, maxdist);
 			for (std::set<Package>::const_iterator it = result.begin(); it != result.end(); ++it)
 			{
-				_searchResult.insert(it->name());
+				_searchResult.insert(*it);
 			}
 		}
 	}
@@ -217,4 +217,4 @@ void RelatedPlugin::setWidgetsEnabled(bool enabled)
 }	// namespace NPlugin
 
 #undef emit
-#include <ept/cache/debtags/tagmap.tcc>
+#include <ept/debtags/debtags.tcc>
